==> developer-center-api-3.5.64-20200724.023946-8-sources.jar: cn/com/duiba/developer/center/api/domain/paramquery/AppUrlParams.java <==
package cn.com.duiba.developer.center.api.domain.paramquery;

import javax.validation.constraints.NotNull;
import java.io.Serializable;

/**
 * Created by liuyao on 16/8/2.
 */
public class AppUrlParams implements Serializable{
    private static final long serialVersionUID = 7895917568144028211L;
    @NotNull
    private Long id;
    private String earnCreditsUrl;//赚取积分链接
    private String recordNotifyUrl;//兑换记录通知链接
    private String virtualExchangeUrl; //虚拟商品充值接口
    private String creditsRemainQueryUrl;// ;积分余额查询地址
    private String creditsConsumeRequestUrl; // 积分扣除地址
    private String creditsConsumeNotifyUrl; // 积分消耗的结果通知地址
    private String addCreditsUrl;//加积分接口
    private String taskListUrl;//任务列表接口

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getEarnCreditsUrl() {
        return earnCreditsUrl;
    }

    public void setEarnCreditsUrl(String earnCreditsUrl) {
        this.earnCreditsUrl = earnCreditsUrl;
    }

    public String getRecordNotifyUrl() {
        return recordNotifyUrl;
    }

    public void setRecordNotifyUrl(String recordNotifyUrl) {
        this.recordNotifyUrl = recordNotifyUrl;
    }

    public String getVirtualExchangeUrl() {
        return virtualExchangeUrl;
    }

    public void setVirtualExchangeUrl(String virtualExchangeUrl) {
        this.virtualExchangeUrl = virtualExchangeUrl;
    }

    public String getCreditsRemainQueryUrl() {
        return creditsRemainQueryUrl;
    }

    public void setCreditsRemainQueryUrl(String creditsRemainQueryUrl) {
        this.creditsRemainQueryUrl = creditsRemainQueryUrl;
    }

    public String getCreditsConsumeRequestUrl() {
        return creditsConsumeRequestUrl;
    }

    public void setCreditsConsumeRequestUrl(String creditsConsumeRequestUrl) {
        this.creditsConsumeRequestUrl = creditsConsumeRequestUrl;
    }

    public String getCreditsConsumeNotifyUrl() {
        return creditsConsumeNotifyUrl;
    }

    public void setCreditsConsumeNotifyUrl(String creditsConsumeNotifyUrl) {
        this.creditsConsumeNotifyUrl = creditsConsumeNotifyUrl;
    }

    public String getAddCreditsUrl() {
        return addCreditsUrl;
    }

    public void setAddCreditsUrl(String addCreditsUrl) {
        this.addCreditsUrl = addCreditsUrl;
    }

    public String getTaskListUrl() {
        return taskListUrl;
    }

    public void setTaskListUrl(String taskListUrl) {
        this.taskListUrl = taskListUrl;
    }
}

==> developer-center-api-3.11.8-20250929.063533-1-sources.jar: cn/com/duiba/developer/center/api/domain/paramquery/AppUrlParams.java <==
package cn.com.duiba.developer.center.api.domain.paramquery;

import javax.validation.constraints.NotNull;
import java.io.Serializable;

/**
 * Created by liuyao on 16/8/2.
 */
public class AppUrlParams implements Serializable{
    private static final long serialVersionUID = 7895917568144028211L;
    @NotNull
    private Long id;
    private String earnCreditsUrl;//赚取积分链接
    private String recordNotifyUrl;//兑换记录通知链接
    private String virtualExchangeUrl; //虚拟商品充值接口
    private String creditsRemainQueryUrl;// ;积分余额查询地址
    private String creditsConsumeRequestUrl; // 积分扣除地址
    private String creditsConsumeNotifyUrl; // 积分消耗的结果通知地址
    private String addCreditsUrl;//加积分接口
    private String taskListUrl;//任务列表接口
    private String postsaleNotifyUrl;//完成售后通知接口

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getEarnCreditsUrl() {
        return earnCreditsUrl;
    }

    public void setEarnCreditsUrl(String earnCreditsUrl) {
        this.earnCreditsUrl = earnCreditsUrl;
    }

    public String getRecordNotifyUrl() {
        return recordNotifyUrl;
    }

    public void setRecordNotifyUrl(String recordNotifyUrl) {
        this.recordNotifyUrl = recordNotifyUrl;
    }

    public String getVirtualExchangeUrl() {
        return virtualExchangeUrl;
    }

    public void setVirtualExchangeUrl(String virtualExchangeUrl) {
        this.virtualExchangeUrl = virtualExchangeUrl;
    }

    public String getCreditsRemainQueryUrl() {
        return creditsRemainQueryUrl;
    }

    public void setCreditsRemainQueryUrl(String creditsRemainQueryUrl) {
        this.creditsRemainQueryUrl = creditsRemainQueryUrl;
    }

    public String getCreditsConsumeRequestUrl() {
        return creditsConsumeRequestUrl;
    }

    public void setCreditsConsumeRequestUrl(String creditsConsumeRequestUrl) {
        this.creditsConsumeRequestUrl = creditsConsumeRequestUrl;
    }

    public String getCreditsConsumeNotifyUrl() {
        return creditsConsumeNotifyUrl;
    }

    public void setCreditsConsumeNotifyUrl(String creditsConsumeNotifyUrl) {
        this.creditsConsumeNotifyUrl = creditsConsumeNotifyUrl;
    }

    public String getAddCreditsUrl() {
        return addCreditsUrl;
    }

    public void setAddCreditsUrl(String addCreditsUrl) {
        this.addCreditsUrl = addCreditsUrl;
    }

    public String getTaskListUrl() {
        return taskListUrl;
    }

    public void setTaskListUrl(String taskListUrl) {
        this.taskListUrl = taskListUrl;
    }

    public String getPostsaleNotifyUrl() {
        return postsaleNotifyUrl;
    }

    public void setPostsaleNotifyUrl(String postsaleNotifyUrl) {
        this.postsaleNotifyUrl = postsaleNotifyUrl;
    }
}
